@@ -5,7 +5,7 @@ use base qw( Data::Phrasebook::Loader::Base Data::Phrasebook::Debug );
 use Carp qw( croak );
 use YAML;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 NAME
 
@@ -90,6 +90,7 @@ Returns the phrase stored in the phrasebook, for a given keyword.
 
 sub get {
 	my ($class,$key) = @_;
+	return undef	unless($key);
 	return undef	unless($class->{yaml});
 	$class->{yaml}->{$key};
 }
@@ -114,6 +115,14 @@ able to pinpoint problems or even supply a patch.
 Fixes are dependant upon their severity and my availablity. Should a fix not
 be forthcoming, please feel free to (politely) remind me.
 
+=head1 DSLIP
+
+  b - Beta testing
+  d - Developer
+  p - Perl-only
+  O - Object oriented
+  p - Standard-Perl: user may choose between GPL and Artistic
+
 =head1 AUTHOR
 
 Original author: Iain Campbell Truskett (16.07.1979 - 29.12.2003).
